@@ -3,12 +3,14 @@ package Markdent::Parser;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
+use Class::MOP;
 use Markdent::Dialect::Standard::BlockParser;
 use Markdent::Dialect::Standard::SpanParser;
 use Markdent::Types qw( Str HashRef BlockParserClass SpanParserClass );
 use MooseX::Params::Validate qw( validated_list );
+use Try::Tiny;
 
 use namespace::autoclean;
 use Moose;
@@ -18,7 +20,7 @@ use MooseX::StrictConstructor;
 with 'Markdent::Role::AnyParser';
 
 has _block_parser_class => (
-    is       => 'ro',
+    is       => 'rw',
     isa      => BlockParserClass,
     init_arg => 'block_parser_class',
     default  => 'Markdent::Dialect::Standard::BlockParser',
@@ -39,7 +41,7 @@ has _block_parser_args => (
 );
 
 has _span_parser_class => (
-    is       => 'ro',
+    is       => 'rw',
     does     => SpanParserClass,
     init_arg => 'span_parser_class',
     default  => 'Markdent::Dialect::Standard::SpanParser',
@@ -63,6 +65,8 @@ sub BUILD {
     my $self = shift;
     my $args = shift;
 
+    $self->_set_classes_for_dialect($args);
+
     my %sp_args;
     for my $key (
         grep {defined}
@@ -95,6 +99,60 @@ sub BUILD {
     $self->_set_block_parser_args(\%bp_args);
 }
 
+sub _set_classes_for_dialect {
+    my $self    = shift;
+    my $args    = shift;
+
+    my $dialect = delete $args->{dialect}
+        or return;
+
+    for my $pair (
+        map { [ $_, $self->_class_name_for_dialect( $dialect, $_ ) ] }
+        qw( block_parser span_parser ) ) {
+
+        my ( $thing, $class ) = @{$pair};
+
+        my $loaded;
+        try {
+            Class::MOP::load_class($class);
+            $loaded = 1;
+        }
+        catch {
+
+            # XXX - This is kind of broken, since a user can typo a dialect
+            # and that will just get ignored.
+            die $_ unless $_ =~ /Can't locate/;
+        };
+
+        next unless $loaded;
+
+        if ( exists $args->{ $thing . '_class' } ) {
+            die
+                "You specified a dialect ($dialect) which has its own $thing class"
+                . " and you also specified an explicit $thing class."
+                . " You cannot specify both when creating a Markdent::Parser.";
+        }
+
+        my $meth = '_set_' . $thing . '_class';
+        $self->$meth($class);
+    }
+}
+
+sub _class_name_for_dialect {
+    my $self    = shift;
+    my $dialect = shift;
+    my $type    = shift;
+
+    my $suffix = join q{}, map {ucfirst} split /_/, $type;
+
+    if ( $dialect =~ /::/ ) {
+        return join '::', $dialect, $suffix;
+    }
+    else {
+        return join '::', 'Markdent::Dialect', $dialect, $suffix;
+    }
+}
+
 sub _build_block_parser {
     my $self = shift;
 
@@ -178,6 +236,23 @@ This method creates a new parser. It accepts the following parameters:
 
 =over 4
 
+=item * dialect => $name
+
+You can use this as a shorthand to pick a block and/or span parser class.
+
+If the dialect parameter does not contain a namespace separator (::), the
+constructor looks for classes named
+C<Markdent::Dialect::${dialect}::BlockParser> and
+C<Markdent::Dialect::${dialect}::SpanParser>.
+
+If the dialect parameter does contain a namespace separator, it is used a
+prefix - C<$dialect::BlockParser> and C<$dialect::SpanParser>.
+
+If any relevant classes are found, they will be used by the parser.
+
+You can I<also> specify an explicit block or span parser, but if the dialect
+has its own class of that type, an error will be thrown.
+
 =item * block_parser_class => $class
 
 This default to L<Markdent::Dialect::Standard::BlockParser>, but can be any
