@@ -3,10 +3,11 @@ package Markdent::Role::DebugPrinter;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Markdent::Types qw( Bool );
 
+use namespace::autoclean;
 use Moose::Role;
 
 has debug => (
@@ -38,8 +39,6 @@ sub _print_debug {
     warn $HR1 . "\n" . ( ref $_[0] ) . "\n" . $_[1] . "\n";
 }
 
-no Moose::Role;
-
 1;
 
 __END__
