@@ -3,16 +3,15 @@ package Markdent::Role::SpanParser;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
+use namespace::autoclean;
 use Moose::Role;
 
 with 'Markdent::Role::AnyParser';
 
 requires 'parse_block';
 
-no Moose::Role;
-
 1;
 
 __END__
